# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ExtensionSettingErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ExtensionSettingErrorValue = typing___NewType(
        "ExtensionSettingErrorValue", builtin___int
    )
    type___ExtensionSettingErrorValue = ExtensionSettingErrorValue
    ExtensionSettingError: _ExtensionSettingError
    class _ExtensionSettingError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 0
        )
        UNKNOWN = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 1)
        EXTENSIONS_REQUIRED = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 2
        )
        FEED_TYPE_EXTENSION_TYPE_MISMATCH = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 3
        )
        INVALID_FEED_TYPE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 4
        )
        INVALID_FEED_TYPE_FOR_CUSTOMER_EXTENSION_SETTING = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 5
        )
        CANNOT_CHANGE_FEED_ITEM_ON_CREATE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 6
        )
        CANNOT_UPDATE_NEWLY_CREATED_EXTENSION = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 7
        )
        NO_EXISTING_AD_GROUP_EXTENSION_SETTING_FOR_TYPE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 8
        )
        NO_EXISTING_CAMPAIGN_EXTENSION_SETTING_FOR_TYPE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 9
        )
        NO_EXISTING_CUSTOMER_EXTENSION_SETTING_FOR_TYPE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 10
        )
        AD_GROUP_EXTENSION_SETTING_ALREADY_EXISTS = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 11
        )
        CAMPAIGN_EXTENSION_SETTING_ALREADY_EXISTS = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 12
        )
        CUSTOMER_EXTENSION_SETTING_ALREADY_EXISTS = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 13
        )
        AD_GROUP_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 14
        )
        CAMPAIGN_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 15
        )
        CUSTOMER_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 16
        )
        VALUE_OUT_OF_RANGE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 17
        )
        CANNOT_SET_FIELD_WITH_FINAL_URLS = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 18
        )
        FINAL_URLS_NOT_SET = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 19
        )
        INVALID_PHONE_NUMBER = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 20
        )
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 21
        )
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 22
        )
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 23
        )
        DISALLOWED_NUMBER_TYPE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 24
        )
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 25
        )
        VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 26
        )
        INVALID_COUNTRY_CODE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 27
        )
        INVALID_CALL_CONVERSION_TYPE_ID = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 28
        )
        CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 29
        )
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 30
        )
        INVALID_APP_ID = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 31
        )
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 32
        )
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 33
        )
        REVIEW_EXTENSION_SOURCE_NOT_ELIGIBLE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 34
        )
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 35
        )
        MISSING_FIELD = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 36
        )
        INCONSISTENT_CURRENCY_CODES = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 37
        )
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 38
        )
        PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 39
        )
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 40
        )
        PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 41
        )
        UNSUPPORTED_VALUE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 42
        )
        INVALID_DEVICE_PREFERENCE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 43
        )
        INVALID_SCHEDULE_END = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 45
        )
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 47
        )
        OVERLAPPING_SCHEDULES_NOT_ALLOWED = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 48
        )
        SCHEDULE_END_NOT_AFTER_START = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 49
        )
        TOO_MANY_SCHEDULES_PER_DAY = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 50
        )
        DUPLICATE_EXTENSION_FEED_ITEM_EDIT = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 51
        )
        INVALID_SNIPPETS_HEADER = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 52
        )
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 53
        )
        CAMPAIGN_TARGETING_MISMATCH = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 54
        )
        CANNOT_OPERATE_ON_REMOVED_FEED = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 55
        )
        EXTENSION_TYPE_REQUIRED = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 56
        )
        INCOMPATIBLE_UNDERLYING_MATCHING_FUNCTION = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 57
        )
        START_DATE_AFTER_END_DATE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 58
        )
        INVALID_PRICE_FORMAT = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 59
        )
        PROMOTION_INVALID_TIME = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 60
        )
        PROMOTION_CANNOT_SET_PERCENT_DISCOUNT_AND_MONEY_DISCOUNT = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 61
        )
        PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 62
        )
        TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 63
        )
        INVALID_LANGUAGE_CODE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 64
        )
        UNSUPPORTED_LANGUAGE = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 65
        )
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 66
        )
        EXTENSION_SETTING_UPDATE_IS_A_NOOP = typing___cast(
            ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 67
        )
    UNSPECIFIED = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 0)
    UNKNOWN = typing___cast(ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 1)
    EXTENSIONS_REQUIRED = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 2
    )
    FEED_TYPE_EXTENSION_TYPE_MISMATCH = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 3
    )
    INVALID_FEED_TYPE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 4
    )
    INVALID_FEED_TYPE_FOR_CUSTOMER_EXTENSION_SETTING = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 5
    )
    CANNOT_CHANGE_FEED_ITEM_ON_CREATE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 6
    )
    CANNOT_UPDATE_NEWLY_CREATED_EXTENSION = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 7
    )
    NO_EXISTING_AD_GROUP_EXTENSION_SETTING_FOR_TYPE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 8
    )
    NO_EXISTING_CAMPAIGN_EXTENSION_SETTING_FOR_TYPE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 9
    )
    NO_EXISTING_CUSTOMER_EXTENSION_SETTING_FOR_TYPE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 10
    )
    AD_GROUP_EXTENSION_SETTING_ALREADY_EXISTS = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 11
    )
    CAMPAIGN_EXTENSION_SETTING_ALREADY_EXISTS = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 12
    )
    CUSTOMER_EXTENSION_SETTING_ALREADY_EXISTS = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 13
    )
    AD_GROUP_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 14
    )
    CAMPAIGN_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 15
    )
    CUSTOMER_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 16
    )
    VALUE_OUT_OF_RANGE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 17
    )
    CANNOT_SET_FIELD_WITH_FINAL_URLS = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 18
    )
    FINAL_URLS_NOT_SET = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 19
    )
    INVALID_PHONE_NUMBER = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 20
    )
    PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 21
    )
    CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 22
    )
    PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 23
    )
    DISALLOWED_NUMBER_TYPE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 24
    )
    INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 25
    )
    VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 26
    )
    INVALID_COUNTRY_CODE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 27
    )
    INVALID_CALL_CONVERSION_TYPE_ID = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 28
    )
    CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 29
    )
    CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 30
    )
    INVALID_APP_ID = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 31
    )
    QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 32
    )
    HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 33
    )
    REVIEW_EXTENSION_SOURCE_NOT_ELIGIBLE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 34
    )
    SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 35
    )
    MISSING_FIELD = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 36
    )
    INCONSISTENT_CURRENCY_CODES = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 37
    )
    PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 38
    )
    PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 39
    )
    PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 40
    )
    PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 41
    )
    UNSUPPORTED_VALUE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 42
    )
    INVALID_DEVICE_PREFERENCE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 43
    )
    INVALID_SCHEDULE_END = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 45
    )
    DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 47
    )
    OVERLAPPING_SCHEDULES_NOT_ALLOWED = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 48
    )
    SCHEDULE_END_NOT_AFTER_START = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 49
    )
    TOO_MANY_SCHEDULES_PER_DAY = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 50
    )
    DUPLICATE_EXTENSION_FEED_ITEM_EDIT = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 51
    )
    INVALID_SNIPPETS_HEADER = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 52
    )
    PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 53
    )
    CAMPAIGN_TARGETING_MISMATCH = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 54
    )
    CANNOT_OPERATE_ON_REMOVED_FEED = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 55
    )
    EXTENSION_TYPE_REQUIRED = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 56
    )
    INCOMPATIBLE_UNDERLYING_MATCHING_FUNCTION = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 57
    )
    START_DATE_AFTER_END_DATE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 58
    )
    INVALID_PRICE_FORMAT = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 59
    )
    PROMOTION_INVALID_TIME = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 60
    )
    PROMOTION_CANNOT_SET_PERCENT_DISCOUNT_AND_MONEY_DISCOUNT = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 61
    )
    PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 62
    )
    TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 63
    )
    INVALID_LANGUAGE_CODE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 64
    )
    UNSUPPORTED_LANGUAGE = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 65
    )
    CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 66
    )
    EXTENSION_SETTING_UPDATE_IS_A_NOOP = typing___cast(
        ExtensionSettingErrorEnum.ExtensionSettingErrorValue, 67
    )
    type___ExtensionSettingError = ExtensionSettingError
    def __init__(self,) -> None: ...

type___ExtensionSettingErrorEnum = ExtensionSettingErrorEnum



# Stubs for google.ads.google_ads.v6.services.transports.ad_group_criterion_service_grpc_transport (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

class AdGroupCriterionServiceGrpcTransport:
    def __init__(
        self,
        channel: Optional[Any] = ...,
        credentials: Optional[Any] = ...,
        address: str = ...,
    ) -> None: ...
    @classmethod
    def create_channel(
        cls, address: str = ..., credentials: Optional[Any] = ..., **kwargs: Any
    ): ...
    @property
    def channel(self): ...
    @property
    def get_ad_group_criterion(self): ...
    @property
    def mutate_ad_group_criteria(self): ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.common.criteria_pb2 import (
    AdScheduleInfo as google___ads___googleads___v4___common___criteria_pb2___AdScheduleInfo,
    KeywordInfo as google___ads___googleads___v4___common___criteria_pb2___KeywordInfo,
)
from google.ads.google_ads.v4.proto.common.extensions_pb2 import (
    AffiliateLocationFeedItem as google___ads___googleads___v4___common___extensions_pb2___AffiliateLocationFeedItem,
    AppFeedItem as google___ads___googleads___v4___common___extensions_pb2___AppFeedItem,
    CallFeedItem as google___ads___googleads___v4___common___extensions_pb2___CallFeedItem,
    CalloutFeedItem as google___ads___googleads___v4___common___extensions_pb2___CalloutFeedItem,
    HotelCalloutFeedItem as google___ads___googleads___v4___common___extensions_pb2___HotelCalloutFeedItem,
    LocationFeedItem as google___ads___googleads___v4___common___extensions_pb2___LocationFeedItem,
    PriceFeedItem as google___ads___googleads___v4___common___extensions_pb2___PriceFeedItem,
    PromotionFeedItem as google___ads___googleads___v4___common___extensions_pb2___PromotionFeedItem,
    SitelinkFeedItem as google___ads___googleads___v4___common___extensions_pb2___SitelinkFeedItem,
    StructuredSnippetFeedItem as google___ads___googleads___v4___common___extensions_pb2___StructuredSnippetFeedItem,
    TextMessageFeedItem as google___ads___googleads___v4___common___extensions_pb2___TextMessageFeedItem,
)
from google.ads.google_ads.v4.proto.enums.extension_type_pb2 import (
    ExtensionTypeEnum as google___ads___googleads___v4___enums___extension_type_pb2___ExtensionTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.feed_item_status_pb2 import (
    FeedItemStatusEnum as google___ads___googleads___v4___enums___feed_item_status_pb2___FeedItemStatusEnum,
)
from google.ads.google_ads.v4.proto.enums.feed_item_target_device_pb2 import (
    FeedItemTargetDeviceEnum as google___ads___googleads___v4___enums___feed_item_target_device_pb2___FeedItemTargetDeviceEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ExtensionFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    extension_type: google___ads___googleads___v4___enums___extension_type_pb2___ExtensionTypeEnum.ExtensionTypeValue = ...
    device: google___ads___googleads___v4___enums___feed_item_target_device_pb2___FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue = ...
    status: google___ads___googleads___v4___enums___feed_item_status_pb2___FeedItemStatusEnum.FeedItemStatusValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def start_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def end_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def ad_schedules(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v4___common___criteria_pb2___AdScheduleInfo
    ]: ...
    @property
    def targeted_geo_target_constant(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def targeted_keyword(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___KeywordInfo: ...
    @property
    def sitelink_feed_item(
        self,
    ) -> google___ads___googleads___v4___common___extensions_pb2___SitelinkFeedItem: ...
    @property
    def structured_snippet_feed_item(
        self,
    ) -> google___ads___googleads___v4___common___extensions_pb2___StructuredSnippetFeedItem: ...
    @property
    def app_feed_item(
        self,
    ) -> google___ads___googleads___v4___common___extensions_pb2___AppFeedItem: ...
    @property
    def call_feed_item(
        self,
    ) -> google___ads___googleads___v4___common___extensions_pb2___CallFeedItem: ...
    @property
    def callout_feed_item(
        self,
    ) -> google___ads___googleads___v4___common___extensions_pb2___CalloutFeedItem: ...
    @property
    def text_message_feed_item(
        self,
    ) -> google___ads___googleads___v4___common___extensions_pb2___TextMessageFeedItem: ...
    @property
    def price_feed_item(
        self,
    ) -> google___ads___googleads___v4___common___extensions_pb2___PriceFeedItem: ...
    @property
    def promotion_feed_item(
        self,
    ) -> google___ads___googleads___v4___common___extensions_pb2___PromotionFeedItem: ...
    @property
    def location_feed_item(
        self,
    ) -> google___ads___googleads___v4___common___extensions_pb2___LocationFeedItem: ...
    @property
    def affiliate_location_feed_item(
        self,
    ) -> google___ads___googleads___v4___common___extensions_pb2___AffiliateLocationFeedItem: ...
    @property
    def hotel_callout_feed_item(
        self,
    ) -> google___ads___googleads___v4___common___extensions_pb2___HotelCalloutFeedItem: ...
    @property
    def targeted_campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def targeted_ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        extension_type: typing___Optional[
            google___ads___googleads___v4___enums___extension_type_pb2___ExtensionTypeEnum.ExtensionTypeValue
        ] = None,
        start_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        end_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        ad_schedules: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v4___common___criteria_pb2___AdScheduleInfo
            ]
        ] = None,
        device: typing___Optional[
            google___ads___googleads___v4___enums___feed_item_target_device_pb2___FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue
        ] = None,
        targeted_geo_target_constant: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        targeted_keyword: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___KeywordInfo
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v4___enums___feed_item_status_pb2___FeedItemStatusEnum.FeedItemStatusValue
        ] = None,
        sitelink_feed_item: typing___Optional[
            google___ads___googleads___v4___common___extensions_pb2___SitelinkFeedItem
        ] = None,
        structured_snippet_feed_item: typing___Optional[
            google___ads___googleads___v4___common___extensions_pb2___StructuredSnippetFeedItem
        ] = None,
        app_feed_item: typing___Optional[
            google___ads___googleads___v4___common___extensions_pb2___AppFeedItem
        ] = None,
        call_feed_item: typing___Optional[
            google___ads___googleads___v4___common___extensions_pb2___CallFeedItem
        ] = None,
        callout_feed_item: typing___Optional[
            google___ads___googleads___v4___common___extensions_pb2___CalloutFeedItem
        ] = None,
        text_message_feed_item: typing___Optional[
            google___ads___googleads___v4___common___extensions_pb2___TextMessageFeedItem
        ] = None,
        price_feed_item: typing___Optional[
            google___ads___googleads___v4___common___extensions_pb2___PriceFeedItem
        ] = None,
        promotion_feed_item: typing___Optional[
            google___ads___googleads___v4___common___extensions_pb2___PromotionFeedItem
        ] = None,
        location_feed_item: typing___Optional[
            google___ads___googleads___v4___common___extensions_pb2___LocationFeedItem
        ] = None,
        affiliate_location_feed_item: typing___Optional[
            google___ads___googleads___v4___common___extensions_pb2___AffiliateLocationFeedItem
        ] = None,
        hotel_callout_feed_item: typing___Optional[
            google___ads___googleads___v4___common___extensions_pb2___HotelCalloutFeedItem
        ] = None,
        targeted_campaign: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        targeted_ad_group: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "affiliate_location_feed_item",
            b"affiliate_location_feed_item",
            "app_feed_item",
            b"app_feed_item",
            "call_feed_item",
            b"call_feed_item",
            "callout_feed_item",
            b"callout_feed_item",
            "end_date_time",
            b"end_date_time",
            "extension",
            b"extension",
            "hotel_callout_feed_item",
            b"hotel_callout_feed_item",
            "id",
            b"id",
            "location_feed_item",
            b"location_feed_item",
            "price_feed_item",
            b"price_feed_item",
            "promotion_feed_item",
            b"promotion_feed_item",
            "serving_resource_targeting",
            b"serving_resource_targeting",
            "sitelink_feed_item",
            b"sitelink_feed_item",
            "start_date_time",
            b"start_date_time",
            "structured_snippet_feed_item",
            b"structured_snippet_feed_item",
            "targeted_ad_group",
            b"targeted_ad_group",
            "targeted_campaign",
            b"targeted_campaign",
            "targeted_geo_target_constant",
            b"targeted_geo_target_constant",
            "targeted_keyword",
            b"targeted_keyword",
            "text_message_feed_item",
            b"text_message_feed_item",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_schedules",
            b"ad_schedules",
            "affiliate_location_feed_item",
            b"affiliate_location_feed_item",
            "app_feed_item",
            b"app_feed_item",
            "call_feed_item",
            b"call_feed_item",
            "callout_feed_item",
            b"callout_feed_item",
            "device",
            b"device",
            "end_date_time",
            b"end_date_time",
            "extension",
            b"extension",
            "extension_type",
            b"extension_type",
            "hotel_callout_feed_item",
            b"hotel_callout_feed_item",
            "id",
            b"id",
            "location_feed_item",
            b"location_feed_item",
            "price_feed_item",
            b"price_feed_item",
            "promotion_feed_item",
            b"promotion_feed_item",
            "resource_name",
            b"resource_name",
            "serving_resource_targeting",
            b"serving_resource_targeting",
            "sitelink_feed_item",
            b"sitelink_feed_item",
            "start_date_time",
            b"start_date_time",
            "status",
            b"status",
            "structured_snippet_feed_item",
            b"structured_snippet_feed_item",
            "targeted_ad_group",
            b"targeted_ad_group",
            "targeted_campaign",
            b"targeted_campaign",
            "targeted_geo_target_constant",
            b"targeted_geo_target_constant",
            "targeted_keyword",
            b"targeted_keyword",
            "text_message_feed_item",
            b"text_message_feed_item",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["extension", b"extension"]
    ) -> typing_extensions___Literal[
        "sitelink_feed_item",
        "structured_snippet_feed_item",
        "app_feed_item",
        "call_feed_item",
        "callout_feed_item",
        "text_message_feed_item",
        "price_feed_item",
        "promotion_feed_item",
        "location_feed_item",
        "affiliate_location_feed_item",
        "hotel_callout_feed_item",
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "serving_resource_targeting", b"serving_resource_targeting"
        ],
    ) -> typing_extensions___Literal["targeted_campaign", "targeted_ad_group"]: ...

type___ExtensionFeedItem = ExtensionFeedItem



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PolicyReviewStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PolicyReviewStatusValue = typing___NewType("PolicyReviewStatusValue", builtin___int)
    type___PolicyReviewStatusValue = PolicyReviewStatusValue
    PolicyReviewStatus: _PolicyReviewStatus
    class _PolicyReviewStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PolicyReviewStatusEnum.PolicyReviewStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(PolicyReviewStatusEnum.PolicyReviewStatusValue, 0)
        UNKNOWN = typing___cast(PolicyReviewStatusEnum.PolicyReviewStatusValue, 1)
        REVIEW_IN_PROGRESS = typing___cast(
            PolicyReviewStatusEnum.PolicyReviewStatusValue, 2
        )
        REVIEWED = typing___cast(PolicyReviewStatusEnum.PolicyReviewStatusValue, 3)
        UNDER_APPEAL = typing___cast(PolicyReviewStatusEnum.PolicyReviewStatusValue, 4)
        ELIGIBLE_MAY_SERVE = typing___cast(
            PolicyReviewStatusEnum.PolicyReviewStatusValue, 5
        )
    UNSPECIFIED = typing___cast(PolicyReviewStatusEnum.PolicyReviewStatusValue, 0)
    UNKNOWN = typing___cast(PolicyReviewStatusEnum.PolicyReviewStatusValue, 1)
    REVIEW_IN_PROGRESS = typing___cast(
        PolicyReviewStatusEnum.PolicyReviewStatusValue, 2
    )
    REVIEWED = typing___cast(PolicyReviewStatusEnum.PolicyReviewStatusValue, 3)
    UNDER_APPEAL = typing___cast(PolicyReviewStatusEnum.PolicyReviewStatusValue, 4)
    ELIGIBLE_MAY_SERVE = typing___cast(
        PolicyReviewStatusEnum.PolicyReviewStatusValue, 5
    )
    type___PolicyReviewStatus = PolicyReviewStatus
    def __init__(self,) -> None: ...

type___PolicyReviewStatusEnum = PolicyReviewStatusEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class LeadFormCallToActionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    LeadFormCallToActionTypeValue = typing___NewType(
        "LeadFormCallToActionTypeValue", builtin___int
    )
    type___LeadFormCallToActionTypeValue = LeadFormCallToActionTypeValue
    LeadFormCallToActionType: _LeadFormCallToActionType
    class _LeadFormCallToActionType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 0
        )
        UNKNOWN = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 1
        )
        LEARN_MORE = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 2
        )
        GET_QUOTE = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 3
        )
        APPLY_NOW = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 4
        )
        SIGN_UP = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 5
        )
        CONTACT_US = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 6
        )
        SUBSCRIBE = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 7
        )
        DOWNLOAD = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 8
        )
        BOOK_NOW = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 9
        )
        GET_OFFER = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 10
        )
        REGISTER = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 11
        )
        GET_INFO = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 12
        )
        REQUEST_DEMO = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 13
        )
        JOIN_NOW = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 14
        )
        GET_STARTED = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 15
        )
    UNSPECIFIED = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 0
    )
    UNKNOWN = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 1
    )
    LEARN_MORE = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 2
    )
    GET_QUOTE = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 3
    )
    APPLY_NOW = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 4
    )
    SIGN_UP = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 5
    )
    CONTACT_US = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 6
    )
    SUBSCRIBE = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 7
    )
    DOWNLOAD = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 8
    )
    BOOK_NOW = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 9
    )
    GET_OFFER = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 10
    )
    REGISTER = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 11
    )
    GET_INFO = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 12
    )
    REQUEST_DEMO = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 13
    )
    JOIN_NOW = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 14
    )
    GET_STARTED = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 15
    )
    type___LeadFormCallToActionType = LeadFormCallToActionType
    def __init__(self,) -> None: ...

type___LeadFormCallToActionTypeEnum = LeadFormCallToActionTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdParameterErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdParameterErrorValue = typing___NewType("AdParameterErrorValue", builtin___int)
    type___AdParameterErrorValue = AdParameterErrorValue
    AdParameterError: _AdParameterError
    class _AdParameterError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdParameterErrorEnum.AdParameterErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdParameterErrorEnum.AdParameterErrorValue, 0)
        UNKNOWN = typing___cast(AdParameterErrorEnum.AdParameterErrorValue, 1)
        AD_GROUP_CRITERION_MUST_BE_KEYWORD = typing___cast(
            AdParameterErrorEnum.AdParameterErrorValue, 2
        )
        INVALID_INSERTION_TEXT_FORMAT = typing___cast(
            AdParameterErrorEnum.AdParameterErrorValue, 3
        )
    UNSPECIFIED = typing___cast(AdParameterErrorEnum.AdParameterErrorValue, 0)
    UNKNOWN = typing___cast(AdParameterErrorEnum.AdParameterErrorValue, 1)
    AD_GROUP_CRITERION_MUST_BE_KEYWORD = typing___cast(
        AdParameterErrorEnum.AdParameterErrorValue, 2
    )
    INVALID_INSERTION_TEXT_FORMAT = typing___cast(
        AdParameterErrorEnum.AdParameterErrorValue, 3
    )
    type___AdParameterError = AdParameterError
    def __init__(self,) -> None: ...

type___AdParameterErrorEnum = AdParameterErrorEnum



from typing import Any

class KeywordViewServiceStub:
    GetKeywordView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class KeywordViewServiceServicer:
    def GetKeywordView(self, request: Any, context: Any) -> None: ...

def add_KeywordViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



from typing import Any

class MutateJobServiceStub:
    CreateMutateJob: Any = ...
    GetMutateJob: Any = ...
    ListMutateJobResults: Any = ...
    RunMutateJob: Any = ...
    AddMutateJobOperations: Any = ...
    def __init__(self, channel: Any) -> None: ...

class MutateJobServiceServicer:
    def CreateMutateJob(self, request: Any, context: Any) -> None: ...
    def GetMutateJob(self, request: Any, context: Any) -> None: ...
    def ListMutateJobResults(self, request: Any, context: Any) -> None: ...
    def RunMutateJob(self, request: Any, context: Any) -> None: ...
    def AddMutateJobOperations(self, request: Any, context: Any) -> None: ...

def add_MutateJobServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class SlotEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    SlotValue = typing___NewType("SlotValue", builtin___int)
    type___SlotValue = SlotValue
    Slot: _Slot
    class _Slot(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            SlotEnum.SlotValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(SlotEnum.SlotValue, 0)
        UNKNOWN = typing___cast(SlotEnum.SlotValue, 1)
        SEARCH_SIDE = typing___cast(SlotEnum.SlotValue, 2)
        SEARCH_TOP = typing___cast(SlotEnum.SlotValue, 3)
        SEARCH_OTHER = typing___cast(SlotEnum.SlotValue, 4)
        CONTENT = typing___cast(SlotEnum.SlotValue, 5)
        SEARCH_PARTNER_TOP = typing___cast(SlotEnum.SlotValue, 6)
        SEARCH_PARTNER_OTHER = typing___cast(SlotEnum.SlotValue, 7)
        MIXED = typing___cast(SlotEnum.SlotValue, 8)
    UNSPECIFIED = typing___cast(SlotEnum.SlotValue, 0)
    UNKNOWN = typing___cast(SlotEnum.SlotValue, 1)
    SEARCH_SIDE = typing___cast(SlotEnum.SlotValue, 2)
    SEARCH_TOP = typing___cast(SlotEnum.SlotValue, 3)
    SEARCH_OTHER = typing___cast(SlotEnum.SlotValue, 4)
    CONTENT = typing___cast(SlotEnum.SlotValue, 5)
    SEARCH_PARTNER_TOP = typing___cast(SlotEnum.SlotValue, 6)
    SEARCH_PARTNER_OTHER = typing___cast(SlotEnum.SlotValue, 7)
    MIXED = typing___cast(SlotEnum.SlotValue, 8)
    type___Slot = Slot
    def __init__(self,) -> None: ...

type___SlotEnum = SlotEnum



from typing import Any

class DynamicSearchAdsSearchTermViewServiceStub:
    GetDynamicSearchAdsSearchTermView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class DynamicSearchAdsSearchTermViewServiceServicer:
    def GetDynamicSearchAdsSearchTermView(self, request: Any, context: Any) -> None: ...

def add_DynamicSearchAdsSearchTermViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordPlanCompetitionLevelEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    KeywordPlanCompetitionLevelValue = typing___NewType(
        "KeywordPlanCompetitionLevelValue", builtin___int
    )
    type___KeywordPlanCompetitionLevelValue = KeywordPlanCompetitionLevelValue
    KeywordPlanCompetitionLevel: _KeywordPlanCompetitionLevel
    class _KeywordPlanCompetitionLevel(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 0
        )
        UNKNOWN = typing___cast(
            KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 1
        )
        LOW = typing___cast(
            KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 2
        )
        MEDIUM = typing___cast(
            KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 3
        )
        HIGH = typing___cast(
            KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 4
        )
    UNSPECIFIED = typing___cast(
        KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 0
    )
    UNKNOWN = typing___cast(
        KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 1
    )
    LOW = typing___cast(
        KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 2
    )
    MEDIUM = typing___cast(
        KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 3
    )
    HIGH = typing___cast(
        KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 4
    )
    type___KeywordPlanCompetitionLevel = KeywordPlanCompetitionLevel
    def __init__(self,) -> None: ...

type___KeywordPlanCompetitionLevelEnum = KeywordPlanCompetitionLevelEnum



from typing import Any

class ConversionUploadServiceStub:
    UploadClickConversions: Any = ...
    UploadCallConversions: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ConversionUploadServiceServicer:
    def UploadClickConversions(self, request: Any, context: Any) -> None: ...
    def UploadCallConversions(self, request: Any, context: Any) -> None: ...

def add_ConversionUploadServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



from typing import Any, Optional

from google.protobuf.message import DecodeError as DecodeError

from google.ads.google_ads.errors import GoogleAdsException as GoogleAdsException

class Interceptor:
    @classmethod
    def get_request_id_from_metadata(cls, trailing_metadata: Any): ...
    @classmethod
    def parse_metadata_to_json(cls, metadata: Any): ...
    @classmethod
    def format_json_object(cls, obj: Any): ...
    @classmethod
    def get_trailing_metadata_from_interceptor_exception(cls, exception: Any): ...
    @classmethod
    def get_client_call_details_instance(
        cls, method: Any, timeout: Any, metadata: Any, credentials: Optional[Any] = ...
    ): ...
    def __init__(self, api_version: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignDraftErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CampaignDraftErrorValue = typing___NewType("CampaignDraftErrorValue", builtin___int)
    type___CampaignDraftErrorValue = CampaignDraftErrorValue
    CampaignDraftError: _CampaignDraftError
    class _CampaignDraftError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CampaignDraftErrorEnum.CampaignDraftErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(CampaignDraftErrorEnum.CampaignDraftErrorValue, 0)
        UNKNOWN = typing___cast(CampaignDraftErrorEnum.CampaignDraftErrorValue, 1)
        DUPLICATE_DRAFT_NAME = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 2
        )
        INVALID_STATUS_TRANSITION_FROM_REMOVED = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 3
        )
        INVALID_STATUS_TRANSITION_FROM_PROMOTED = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 4
        )
        INVALID_STATUS_TRANSITION_FROM_PROMOTE_FAILED = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 5
        )
        CUSTOMER_CANNOT_CREATE_DRAFT = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 6
        )
        CAMPAIGN_CANNOT_CREATE_DRAFT = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 7
        )
        INVALID_DRAFT_CHANGE = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 8
        )
        INVALID_STATUS_TRANSITION = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 9
        )
        MAX_NUMBER_OF_DRAFTS_PER_CAMPAIGN_REACHED = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 10
        )
        LIST_ERRORS_FOR_PROMOTED_DRAFT_ONLY = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 11
        )
    UNSPECIFIED = typing___cast(CampaignDraftErrorEnum.CampaignDraftErrorValue, 0)
    UNKNOWN = typing___cast(CampaignDraftErrorEnum.CampaignDraftErrorValue, 1)
    DUPLICATE_DRAFT_NAME = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 2
    )
    INVALID_STATUS_TRANSITION_FROM_REMOVED = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 3
    )
    INVALID_STATUS_TRANSITION_FROM_PROMOTED = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 4
    )
    INVALID_STATUS_TRANSITION_FROM_PROMOTE_FAILED = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 5
    )
    CUSTOMER_CANNOT_CREATE_DRAFT = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 6
    )
    CAMPAIGN_CANNOT_CREATE_DRAFT = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 7
    )
    INVALID_DRAFT_CHANGE = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 8
    )
    INVALID_STATUS_TRANSITION = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 9
    )
    MAX_NUMBER_OF_DRAFTS_PER_CAMPAIGN_REACHED = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 10
    )
    LIST_ERRORS_FOR_PROMOTED_DRAFT_ONLY = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 11
    )
    type___CampaignDraftError = CampaignDraftError
    def __init__(self,) -> None: ...

type___CampaignDraftErrorEnum = CampaignDraftErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class OperatorErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    OperatorErrorValue = typing___NewType("OperatorErrorValue", builtin___int)
    type___OperatorErrorValue = OperatorErrorValue
    OperatorError: _OperatorError
    class _OperatorError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            OperatorErrorEnum.OperatorErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(OperatorErrorEnum.OperatorErrorValue, 0)
        UNKNOWN = typing___cast(OperatorErrorEnum.OperatorErrorValue, 1)
        OPERATOR_NOT_SUPPORTED = typing___cast(OperatorErrorEnum.OperatorErrorValue, 2)
    UNSPECIFIED = typing___cast(OperatorErrorEnum.OperatorErrorValue, 0)
    UNKNOWN = typing___cast(OperatorErrorEnum.OperatorErrorValue, 1)
    OPERATOR_NOT_SUPPORTED = typing___cast(OperatorErrorEnum.OperatorErrorValue, 2)
    type___OperatorError = OperatorError
    def __init__(self,) -> None: ...

type___OperatorErrorEnum = OperatorErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class OfflineUserDataJobErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    OfflineUserDataJobErrorValue = typing___NewType(
        "OfflineUserDataJobErrorValue", builtin___int
    )
    type___OfflineUserDataJobErrorValue = OfflineUserDataJobErrorValue
    OfflineUserDataJobError: _OfflineUserDataJobError
    class _OfflineUserDataJobError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 0
        )
        UNKNOWN = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 1
        )
        INVALID_USER_LIST_ID = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 3
        )
        INVALID_USER_LIST_TYPE = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 4
        )
        NOT_WHITELISTED_FOR_USER_ID = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 5
        )
        INCOMPATIBLE_UPLOAD_KEY_TYPE = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 6
        )
        MISSING_USER_IDENTIFIER = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 7
        )
        INVALID_MOBILE_ID_FORMAT = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 8
        )
        TOO_MANY_USER_IDENTIFIERS = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 9
        )
        NOT_WHITELISTED_FOR_STORE_SALES_DIRECT = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 10
        )
        INVALID_PARTNER_ID = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 11
        )
        INVALID_ENCODING = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 12
        )
        INVALID_COUNTRY_CODE = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 13
        )
        INCOMPATIBLE_USER_IDENTIFIER = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 14
        )
        FUTURE_TRANSACTION_TIME = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 15
        )
        INVALID_CONVERSION_ACTION = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 16
        )
        MOBILE_ID_NOT_SUPPORTED = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 17
        )
        INVALID_OPERATION_ORDER = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 18
        )
        CONFLICTING_OPERATION = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 19
        )
        EXTERNAL_UPDATE_ID_ALREADY_EXISTS = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 21
        )
        JOB_ALREADY_STARTED = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 22
        )
        REMOVE_NOT_SUPPORTED = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 23
        )
        REMOVE_ALL_NOT_SUPPORTED = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 24
        )
        INVALID_SHA256_FORMAT = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 25
        )
    UNSPECIFIED = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 0
    )
    UNKNOWN = typing___cast(OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 1)
    INVALID_USER_LIST_ID = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 3
    )
    INVALID_USER_LIST_TYPE = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 4
    )
    NOT_WHITELISTED_FOR_USER_ID = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 5
    )
    INCOMPATIBLE_UPLOAD_KEY_TYPE = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 6
    )
    MISSING_USER_IDENTIFIER = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 7
    )
    INVALID_MOBILE_ID_FORMAT = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 8
    )
    TOO_MANY_USER_IDENTIFIERS = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 9
    )
    NOT_WHITELISTED_FOR_STORE_SALES_DIRECT = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 10
    )
    INVALID_PARTNER_ID = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 11
    )
    INVALID_ENCODING = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 12
    )
    INVALID_COUNTRY_CODE = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 13
    )
    INCOMPATIBLE_USER_IDENTIFIER = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 14
    )
    FUTURE_TRANSACTION_TIME = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 15
    )
    INVALID_CONVERSION_ACTION = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 16
    )
    MOBILE_ID_NOT_SUPPORTED = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 17
    )
    INVALID_OPERATION_ORDER = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 18
    )
    CONFLICTING_OPERATION = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 19
    )
    EXTERNAL_UPDATE_ID_ALREADY_EXISTS = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 21
    )
    JOB_ALREADY_STARTED = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 22
    )
    REMOVE_NOT_SUPPORTED = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 23
    )
    REMOVE_ALL_NOT_SUPPORTED = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 24
    )
    INVALID_SHA256_FORMAT = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 25
    )
    type___OfflineUserDataJobError = OfflineUserDataJobError
    def __init__(self,) -> None: ...

type___OfflineUserDataJobErrorEnum = OfflineUserDataJobErrorEnum



from typing import Any

class BatchJobServiceStub:
    MutateBatchJob: Any = ...
    GetBatchJob: Any = ...
    ListBatchJobResults: Any = ...
    RunBatchJob: Any = ...
    AddBatchJobOperations: Any = ...
    def __init__(self, channel: Any) -> None: ...

class BatchJobServiceServicer:
    def MutateBatchJob(self, request: Any, context: Any) -> None: ...
    def GetBatchJob(self, request: Any, context: Any) -> None: ...
    def ListBatchJobResults(self, request: Any, context: Any) -> None: ...
    def RunBatchJob(self, request: Any, context: Any) -> None: ...
    def AddBatchJobOperations(self, request: Any, context: Any) -> None: ...

def add_BatchJobServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ChangeEventResourceTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ChangeEventResourceTypeValue = typing___NewType(
        "ChangeEventResourceTypeValue", builtin___int
    )
    type___ChangeEventResourceTypeValue = ChangeEventResourceTypeValue
    ChangeEventResourceType: _ChangeEventResourceType
    class _ChangeEventResourceType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 0
        )
        UNKNOWN = typing___cast(
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 1
        )
        AD = typing___cast(ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 2)
        AD_GROUP = typing___cast(
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 3
        )
        AD_GROUP_CRITERION = typing___cast(
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 4
        )
        CAMPAIGN = typing___cast(
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 5
        )
        CAMPAIGN_BUDGET = typing___cast(
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 6
        )
        AD_GROUP_BID_MODIFIER = typing___cast(
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 7
        )
        CAMPAIGN_CRITERION = typing___cast(
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 8
        )
    UNSPECIFIED = typing___cast(
        ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 0
    )
    UNKNOWN = typing___cast(ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 1)
    AD = typing___cast(ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 2)
    AD_GROUP = typing___cast(
        ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 3
    )
    AD_GROUP_CRITERION = typing___cast(
        ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 4
    )
    CAMPAIGN = typing___cast(
        ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 5
    )
    CAMPAIGN_BUDGET = typing___cast(
        ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 6
    )
    AD_GROUP_BID_MODIFIER = typing___cast(
        ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 7
    )
    CAMPAIGN_CRITERION = typing___cast(
        ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 8
    )
    type___ChangeEventResourceType = ChangeEventResourceType
    def __init__(self,) -> None: ...

type___ChangeEventResourceTypeEnum = ChangeEventResourceTypeEnum



from typing import Any

class AdScheduleViewServiceStub:
    GetAdScheduleView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdScheduleViewServiceServicer:
    def GetAdScheduleView(self, request: Any, context: Any) -> None: ...

def add_AdScheduleViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.keyword_match_type_pb2 import (
    KeywordMatchTypeEnum as google___ads___googleads___v5___enums___keyword_match_type_pb2___KeywordMatchTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordPlanAdGroupKeyword(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    match_type: google___ads___googleads___v5___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchTypeValue = ...
    @property
    def keyword_plan_ad_group(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def text(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def negative(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        keyword_plan_ad_group: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        text: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        match_type: typing___Optional[
            google___ads___googleads___v5___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchTypeValue
        ] = None,
        cpc_bid_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        negative: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "id",
            b"id",
            "keyword_plan_ad_group",
            b"keyword_plan_ad_group",
            "negative",
            b"negative",
            "text",
            b"text",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "id",
            b"id",
            "keyword_plan_ad_group",
            b"keyword_plan_ad_group",
            "match_type",
            b"match_type",
            "negative",
            b"negative",
            "resource_name",
            b"resource_name",
            "text",
            b"text",
        ],
    ) -> None: ...

type___KeywordPlanAdGroupKeyword = KeywordPlanAdGroupKeyword



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdSharingErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdSharingErrorValue = typing___NewType("AdSharingErrorValue", builtin___int)
    type___AdSharingErrorValue = AdSharingErrorValue
    AdSharingError: _AdSharingError
    class _AdSharingError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdSharingErrorEnum.AdSharingErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdSharingErrorEnum.AdSharingErrorValue, 0)
        UNKNOWN = typing___cast(AdSharingErrorEnum.AdSharingErrorValue, 1)
        AD_GROUP_ALREADY_CONTAINS_AD = typing___cast(
            AdSharingErrorEnum.AdSharingErrorValue, 2
        )
        INCOMPATIBLE_AD_UNDER_AD_GROUP = typing___cast(
            AdSharingErrorEnum.AdSharingErrorValue, 3
        )
        CANNOT_SHARE_INACTIVE_AD = typing___cast(
            AdSharingErrorEnum.AdSharingErrorValue, 4
        )
    UNSPECIFIED = typing___cast(AdSharingErrorEnum.AdSharingErrorValue, 0)
    UNKNOWN = typing___cast(AdSharingErrorEnum.AdSharingErrorValue, 1)
    AD_GROUP_ALREADY_CONTAINS_AD = typing___cast(
        AdSharingErrorEnum.AdSharingErrorValue, 2
    )
    INCOMPATIBLE_AD_UNDER_AD_GROUP = typing___cast(
        AdSharingErrorEnum.AdSharingErrorValue, 3
    )
    CANNOT_SHARE_INACTIVE_AD = typing___cast(AdSharingErrorEnum.AdSharingErrorValue, 4)
    type___AdSharingError = AdSharingError
    def __init__(self,) -> None: ...

type___AdSharingErrorEnum = AdSharingErrorEnum



from typing import Any, Optional

class MediaFileServiceStub:
    GetMediaFile: Any = ...
    MutateMediaFiles: Any = ...
    def __init__(self, channel: Any) -> None: ...

class MediaFileServiceServicer:
    def GetMediaFile(self, request: Any, context: Any) -> None: ...
    def MutateMediaFiles(self, request: Any, context: Any) -> None: ...

def add_MediaFileServiceServicer_to_server(servicer: Any, server: Any) -> None: ...

class MediaFileService:
    @staticmethod
    def GetMediaFile(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def MutateMediaFiles(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...



from typing import Any

class BiddingStrategyServiceStub:
    GetBiddingStrategy: Any = ...
    MutateBiddingStrategies: Any = ...
    def __init__(self, channel: Any) -> None: ...

class BiddingStrategyServiceServicer:
    def GetBiddingStrategy(self, request: Any, context: Any) -> None: ...
    def MutateBiddingStrategies(self, request: Any, context: Any) -> None: ...

def add_BiddingStrategyServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordPlanAdGroupKeywordErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    KeywordPlanAdGroupKeywordErrorValue = typing___NewType(
        "KeywordPlanAdGroupKeywordErrorValue", builtin___int
    )
    type___KeywordPlanAdGroupKeywordErrorValue = KeywordPlanAdGroupKeywordErrorValue
    KeywordPlanAdGroupKeywordError: _KeywordPlanAdGroupKeywordError
    class _KeywordPlanAdGroupKeywordError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 0
        )
        UNKNOWN = typing___cast(
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 1
        )
        INVALID_KEYWORD_MATCH_TYPE = typing___cast(
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 2
        )
        DUPLICATE_KEYWORD = typing___cast(
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 3
        )
        KEYWORD_TEXT_TOO_LONG = typing___cast(
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 4
        )
        KEYWORD_HAS_INVALID_CHARS = typing___cast(
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 5
        )
        KEYWORD_HAS_TOO_MANY_WORDS = typing___cast(
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 6
        )
        INVALID_KEYWORD_TEXT = typing___cast(
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 7
        )
        NEGATIVE_KEYWORD_HAS_CPC_BID = typing___cast(
            KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 8
        )
    UNSPECIFIED = typing___cast(
        KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 0
    )
    UNKNOWN = typing___cast(
        KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 1
    )
    INVALID_KEYWORD_MATCH_TYPE = typing___cast(
        KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 2
    )
    DUPLICATE_KEYWORD = typing___cast(
        KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 3
    )
    KEYWORD_TEXT_TOO_LONG = typing___cast(
        KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 4
    )
    KEYWORD_HAS_INVALID_CHARS = typing___cast(
        KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 5
    )
    KEYWORD_HAS_TOO_MANY_WORDS = typing___cast(
        KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 6
    )
    INVALID_KEYWORD_TEXT = typing___cast(
        KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 7
    )
    NEGATIVE_KEYWORD_HAS_CPC_BID = typing___cast(
        KeywordPlanAdGroupKeywordErrorEnum.KeywordPlanAdGroupKeywordErrorValue, 8
    )
    type___KeywordPlanAdGroupKeywordError = KeywordPlanAdGroupKeywordError
    def __init__(self,) -> None: ...

type___KeywordPlanAdGroupKeywordErrorEnum = KeywordPlanAdGroupKeywordErrorEnum



from typing import Any

class CustomerClientServiceStub:
    GetCustomerClient: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CustomerClientServiceServicer:
    def GetCustomerClient(self, request: Any, context: Any) -> None: ...

def add_CustomerClientServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.field_mask_pb2 import (
    FieldMask as google___protobuf___field_mask_pb2___FieldMask,
)
from google.protobuf.internal.containers import (
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.enums.access_role_pb2 import (
    AccessRoleEnum as google___ads___googleads___v4___enums___access_role_pb2___AccessRoleEnum,
)
from google.ads.google_ads.v4.proto.resources.customer_pb2 import (
    Customer as google___ads___googleads___v4___resources___customer_pb2___Customer,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GetCustomerRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___GetCustomerRequest = GetCustomerRequest

class MutateCustomerRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    validate_only: builtin___bool = ...
    @property
    def operation(self) -> type___CustomerOperation: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        operation: typing___Optional[type___CustomerOperation] = None,
        validate_only: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["operation", b"operation"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id",
            b"customer_id",
            "operation",
            b"operation",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

type___MutateCustomerRequest = MutateCustomerRequest

class CreateCustomerClientRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    access_role: google___ads___googleads___v4___enums___access_role_pb2___AccessRoleEnum.AccessRoleValue = ...
    @property
    def customer_client(
        self,
    ) -> google___ads___googleads___v4___resources___customer_pb2___Customer: ...
    @property
    def email_address(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        customer_client: typing___Optional[
            google___ads___googleads___v4___resources___customer_pb2___Customer
        ] = None,
        email_address: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        access_role: typing___Optional[
            google___ads___googleads___v4___enums___access_role_pb2___AccessRoleEnum.AccessRoleValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "customer_client", b"customer_client", "email_address", b"email_address"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "access_role",
            b"access_role",
            "customer_client",
            b"customer_client",
            "customer_id",
            b"customer_id",
            "email_address",
            b"email_address",
        ],
    ) -> None: ...

type___CreateCustomerClientRequest = CreateCustomerClientRequest

class CustomerOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def update(
        self,
    ) -> google___ads___googleads___v4___resources___customer_pb2___Customer: ...
    @property
    def update_mask(self) -> google___protobuf___field_mask_pb2___FieldMask: ...
    def __init__(
        self,
        *,
        update: typing___Optional[
            google___ads___googleads___v4___resources___customer_pb2___Customer
        ] = None,
        update_mask: typing___Optional[
            google___protobuf___field_mask_pb2___FieldMask
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "update", b"update", "update_mask", b"update_mask"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "update", b"update", "update_mask", b"update_mask"
        ],
    ) -> None: ...

type___CustomerOperation = CustomerOperation

class CreateCustomerClientResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    invitation_link: typing___Text = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        invitation_link: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "invitation_link", b"invitation_link", "resource_name", b"resource_name"
        ],
    ) -> None: ...

type___CreateCustomerClientResponse = CreateCustomerClientResponse

class MutateCustomerResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def result(self) -> type___MutateCustomerResult: ...
    def __init__(
        self, *, result: typing___Optional[type___MutateCustomerResult] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["result", b"result"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["result", b"result"]
    ) -> None: ...

type___MutateCustomerResponse = MutateCustomerResponse

class MutateCustomerResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___MutateCustomerResult = MutateCustomerResult

class ListAccessibleCustomersRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    def __init__(self,) -> None: ...

type___ListAccessibleCustomersRequest = ListAccessibleCustomersRequest

class ListAccessibleCustomersResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_names: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        typing___Text
    ] = ...
    def __init__(
        self,
        *,
        resource_names: typing___Optional[typing___Iterable[typing___Text]] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["resource_names", b"resource_names"],
    ) -> None: ...

type___ListAccessibleCustomersResponse = ListAccessibleCustomersResponse



from typing import Any, Dict, Optional, Tuple, Union, overload

from typing_extensions import TypedDict

class _ConfigDataRequired(TypedDict):
    developer_token: str

class _ConfigDataOptional(TypedDict, total=False):
    endpoint: str
    logging: Dict[str, Any]

class _ConfigDataParsedOptional(_ConfigDataOptional, total=False):
    login_customer_id: str

class _ConfigDataUnparsedOptional(_ConfigDataOptional, total=False):
    login_customer_id: Union[int, str]

class _InstalledAppConfigDataRequired(TypedDict):
    client_id: str
    client_secret: str
    refresh_token: str

class _ServiceAccountConfigDataRequired(TypedDict):
    path_to_private_key_file: str
    delegated_account: str

class _InstalledAppConfigData(
    _ConfigDataRequired, _ConfigDataParsedOptional, _InstalledAppConfigDataRequired
):
    pass

class _InstalledAppConfigDataUnparsed(
    _ConfigDataRequired, _ConfigDataUnparsedOptional, _InstalledAppConfigDataRequired
):
    pass

class _ServiceAccountConfigData(
    _ConfigDataRequired, _ConfigDataParsedOptional, _ServiceAccountConfigDataRequired
):
    pass

class _ServiceAccountConfigDataUnparsed(
    _ConfigDataRequired, _ConfigDataUnparsedOptional, _ServiceAccountConfigDataRequired
):
    pass

_ConfigData = Union[_InstalledAppConfigData, _ServiceAccountConfigData]
_ConfigDataUnparsed = Union[
    _InstalledAppConfigDataUnparsed, _ServiceAccountConfigDataUnparsed
]

def validate_dict(config_data: _ConfigData) -> None: ...
def validate_login_customer_id(login_customer_id: Optional[str]) -> None: ...
def load_from_yaml_file(path: Optional[str] = ...) -> _ConfigData: ...
@overload
def load_from_dict(
    config_dict: _InstalledAppConfigDataUnparsed,
) -> _InstalledAppConfigData: ...
@overload
def load_from_dict(
    config_dict: _ServiceAccountConfigDataUnparsed,
) -> _ServiceAccountConfigData: ...
def parse_yaml_document_to_dict(yaml_doc: bytes) -> _ConfigData: ...
def load_from_env() -> _ConfigData: ...
def get_oauth2_installed_app_keys() -> Tuple[str, str, str]: ...
def get_oauth2_service_account_keys() -> Tuple[str, str]: ...
@overload
def convert_login_customer_id_to_str(
    config_data: _InstalledAppConfigDataUnparsed,
) -> _InstalledAppConfigData: ...
@overload
def convert_login_customer_id_to_str(
    config_data: _ServiceAccountConfigDataUnparsed,
) -> _ServiceAccountConfigData: ...



from typing import Any

class IncomeRangeViewServiceStub:
    GetIncomeRangeView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class IncomeRangeViewServiceServicer:
    def GetIncomeRangeView(self, request: Any, context: Any) -> None: ...

def add_IncomeRangeViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



from typing import Any

class CustomerExtensionSettingServiceStub:
    GetCustomerExtensionSetting: Any = ...
    MutateCustomerExtensionSettings: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CustomerExtensionSettingServiceServicer:
    def GetCustomerExtensionSetting(self, request: Any, context: Any) -> None: ...
    def MutateCustomerExtensionSettings(self, request: Any, context: Any) -> None: ...

def add_CustomerExtensionSettingServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.common.custom_parameter_pb2 import (
    CustomParameter as google___ads___googleads___v4___common___custom_parameter_pb2___CustomParameter,
)
from google.ads.google_ads.v4.proto.common.feed_common_pb2 import (
    Money as google___ads___googleads___v4___common___feed_common_pb2___Money,
)
from google.ads.google_ads.v4.proto.enums.app_store_pb2 import (
    AppStoreEnum as google___ads___googleads___v4___enums___app_store_pb2___AppStoreEnum,
)
from google.ads.google_ads.v4.proto.enums.call_conversion_reporting_state_pb2 import (
    CallConversionReportingStateEnum as google___ads___googleads___v4___enums___call_conversion_reporting_state_pb2___CallConversionReportingStateEnum,
)
from google.ads.google_ads.v4.proto.enums.price_extension_price_qualifier_pb2 import (
    PriceExtensionPriceQualifierEnum as google___ads___googleads___v4___enums___price_extension_price_qualifier_pb2___PriceExtensionPriceQualifierEnum,
)
from google.ads.google_ads.v4.proto.enums.price_extension_price_unit_pb2 import (
    PriceExtensionPriceUnitEnum as google___ads___googleads___v4___enums___price_extension_price_unit_pb2___PriceExtensionPriceUnitEnum,
)
from google.ads.google_ads.v4.proto.enums.price_extension_type_pb2 import (
    PriceExtensionTypeEnum as google___ads___googleads___v4___enums___price_extension_type_pb2___PriceExtensionTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.promotion_extension_discount_modifier_pb2 import (
    PromotionExtensionDiscountModifierEnum as google___ads___googleads___v4___enums___promotion_extension_discount_modifier_pb2___PromotionExtensionDiscountModifierEnum,
)
from google.ads.google_ads.v4.proto.enums.promotion_extension_occasion_pb2 import (
    PromotionExtensionOccasionEnum as google___ads___googleads___v4___enums___promotion_extension_occasion_pb2___PromotionExtensionOccasionEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AppFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    app_store: google___ads___googleads___v4___enums___app_store_pb2___AppStoreEnum.AppStoreValue = ...
    @property
    def link_text(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def app_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def final_urls(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def final_mobile_urls(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def tracking_url_template(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def url_custom_parameters(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v4___common___custom_parameter_pb2___CustomParameter
    ]: ...
    @property
    def final_url_suffix(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        link_text: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        app_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        app_store: typing___Optional[
            google___ads___googleads___v4___enums___app_store_pb2___AppStoreEnum.AppStoreValue
        ] = None,
        final_urls: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        final_mobile_urls: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        tracking_url_template: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        url_custom_parameters: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v4___common___custom_parameter_pb2___CustomParameter
            ]
        ] = None,
        final_url_suffix: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "app_id",
            b"app_id",
            "final_url_suffix",
            b"final_url_suffix",
            "link_text",
            b"link_text",
            "tracking_url_template",
            b"tracking_url_template",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "app_id",
            b"app_id",
            "app_store",
            b"app_store",
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_url_suffix",
            b"final_url_suffix",
            "final_urls",
            b"final_urls",
            "link_text",
            b"link_text",
            "tracking_url_template",
            b"tracking_url_template",
            "url_custom_parameters",
            b"url_custom_parameters",
        ],
    ) -> None: ...

type___AppFeedItem = AppFeedItem

class CallFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    call_conversion_reporting_state: google___ads___googleads___v4___enums___call_conversion_reporting_state_pb2___CallConversionReportingStateEnum.CallConversionReportingStateValue = ...
    @property
    def phone_number(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def call_tracking_enabled(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def call_conversion_action(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def call_conversion_tracking_disabled(
        self,
    ) -> google___protobuf___wrappers_pb2___BoolValue: ...
    def __init__(
        self,
        *,
        phone_number: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        country_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        call_tracking_enabled: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        call_conversion_action: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        call_conversion_tracking_disabled: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        call_conversion_reporting_state: typing___Optional[
            google___ads___googleads___v4___enums___call_conversion_reporting_state_pb2___CallConversionReportingStateEnum.CallConversionReportingStateValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "call_conversion_action",
            b"call_conversion_action",
            "call_conversion_tracking_disabled",
            b"call_conversion_tracking_disabled",
            "call_tracking_enabled",
            b"call_tracking_enabled",
            "country_code",
            b"country_code",
            "phone_number",
            b"phone_number",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "call_conversion_action",
            b"call_conversion_action",
            "call_conversion_reporting_state",
            b"call_conversion_reporting_state",
            "call_conversion_tracking_disabled",
            b"call_conversion_tracking_disabled",
            "call_tracking_enabled",
            b"call_tracking_enabled",
            "country_code",
            b"country_code",
            "phone_number",
            b"phone_number",
        ],
    ) -> None: ...

type___CallFeedItem = CallFeedItem

class CalloutFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def callout_text(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        callout_text: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["callout_text", b"callout_text"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["callout_text", b"callout_text"]
    ) -> None: ...

type___CalloutFeedItem = CalloutFeedItem

class LocationFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def business_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def address_line_1(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def address_line_2(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def city(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def province(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def postal_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def phone_number(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        business_name: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        address_line_1: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        address_line_2: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        city: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        province: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        postal_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        country_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        phone_number: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "address_line_1",
            b"address_line_1",
            "address_line_2",
            b"address_line_2",
            "business_name",
            b"business_name",
            "city",
            b"city",
            "country_code",
            b"country_code",
            "phone_number",
            b"phone_number",
            "postal_code",
            b"postal_code",
            "province",
            b"province",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "address_line_1",
            b"address_line_1",
            "address_line_2",
            b"address_line_2",
            "business_name",
            b"business_name",
            "city",
            b"city",
            "country_code",
            b"country_code",
            "phone_number",
            b"phone_number",
            "postal_code",
            b"postal_code",
            "province",
            b"province",
        ],
    ) -> None: ...

type___LocationFeedItem = LocationFeedItem

class AffiliateLocationFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def business_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def address_line_1(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def address_line_2(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def city(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def province(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def postal_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def phone_number(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def chain_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def chain_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        business_name: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        address_line_1: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        address_line_2: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        city: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        province: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        postal_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        country_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        phone_number: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        chain_id: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        chain_name: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "address_line_1",
            b"address_line_1",
            "address_line_2",
            b"address_line_2",
            "business_name",
            b"business_name",
            "chain_id",
            b"chain_id",
            "chain_name",
            b"chain_name",
            "city",
            b"city",
            "country_code",
            b"country_code",
            "phone_number",
            b"phone_number",
            "postal_code",
            b"postal_code",
            "province",
            b"province",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "address_line_1",
            b"address_line_1",
            "address_line_2",
            b"address_line_2",
            "business_name",
            b"business_name",
            "chain_id",
            b"chain_id",
            "chain_name",
            b"chain_name",
            "city",
            b"city",
            "country_code",
            b"country_code",
            "phone_number",
            b"phone_number",
            "postal_code",
            b"postal_code",
            "province",
            b"province",
        ],
    ) -> None: ...

type___AffiliateLocationFeedItem = AffiliateLocationFeedItem

class TextMessageFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def business_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def phone_number(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def text(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def extension_text(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        business_name: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        country_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        phone_number: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        text: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        extension_text: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "business_name",
            b"business_name",
            "country_code",
            b"country_code",
            "extension_text",
            b"extension_text",
            "phone_number",
            b"phone_number",
            "text",
            b"text",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "business_name",
            b"business_name",
            "country_code",
            b"country_code",
            "extension_text",
            b"extension_text",
            "phone_number",
            b"phone_number",
            "text",
            b"text",
        ],
    ) -> None: ...

type___TextMessageFeedItem = TextMessageFeedItem

class PriceFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type: google___ads___googleads___v4___enums___price_extension_type_pb2___PriceExtensionTypeEnum.PriceExtensionTypeValue = ...
    price_qualifier: google___ads___googleads___v4___enums___price_extension_price_qualifier_pb2___PriceExtensionPriceQualifierEnum.PriceExtensionPriceQualifierValue = ...
    @property
    def tracking_url_template(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def language_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def price_offerings(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___PriceOffer
    ]: ...
    @property
    def final_url_suffix(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        type: typing___Optional[
            google___ads___googleads___v4___enums___price_extension_type_pb2___PriceExtensionTypeEnum.PriceExtensionTypeValue
        ] = None,
        price_qualifier: typing___Optional[
            google___ads___googleads___v4___enums___price_extension_price_qualifier_pb2___PriceExtensionPriceQualifierEnum.PriceExtensionPriceQualifierValue
        ] = None,
        tracking_url_template: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        language_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        price_offerings: typing___Optional[typing___Iterable[type___PriceOffer]] = None,
        final_url_suffix: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "final_url_suffix",
            b"final_url_suffix",
            "language_code",
            b"language_code",
            "tracking_url_template",
            b"tracking_url_template",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "final_url_suffix",
            b"final_url_suffix",
            "language_code",
            b"language_code",
            "price_offerings",
            b"price_offerings",
            "price_qualifier",
            b"price_qualifier",
            "tracking_url_template",
            b"tracking_url_template",
            "type",
            b"type",
        ],
    ) -> None: ...

type___PriceFeedItem = PriceFeedItem

class PriceOffer(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    unit: google___ads___googleads___v4___enums___price_extension_price_unit_pb2___PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue = ...
    @property
    def header(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def description(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def price(
        self,
    ) -> google___ads___googleads___v4___common___feed_common_pb2___Money: ...
    @property
    def final_urls(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def final_mobile_urls(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    def __init__(
        self,
        *,
        header: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        description: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        price: typing___Optional[
            google___ads___googleads___v4___common___feed_common_pb2___Money
        ] = None,
        unit: typing___Optional[
            google___ads___googleads___v4___enums___price_extension_price_unit_pb2___PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue
        ] = None,
        final_urls: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        final_mobile_urls: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "description", b"description", "header", b"header", "price", b"price"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "description",
            b"description",
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_urls",
            b"final_urls",
            "header",
            b"header",
            "price",
            b"price",
            "unit",
            b"unit",
        ],
    ) -> None: ...

type___PriceOffer = PriceOffer

class PromotionFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    discount_modifier: google___ads___googleads___v4___enums___promotion_extension_discount_modifier_pb2___PromotionExtensionDiscountModifierEnum.PromotionExtensionDiscountModifierValue = ...
    occasion: google___ads___googleads___v4___enums___promotion_extension_occasion_pb2___PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue = ...
    @property
    def promotion_target(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def promotion_start_date(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def promotion_end_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def final_urls(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def final_mobile_urls(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def tracking_url_template(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def url_custom_parameters(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v4___common___custom_parameter_pb2___CustomParameter
    ]: ...
    @property
    def final_url_suffix(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def language_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def percent_off(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def money_amount_off(
        self,
    ) -> google___ads___googleads___v4___common___feed_common_pb2___Money: ...
    @property
    def promotion_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def orders_over_amount(
        self,
    ) -> google___ads___googleads___v4___common___feed_common_pb2___Money: ...
    def __init__(
        self,
        *,
        promotion_target: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        discount_modifier: typing___Optional[
            google___ads___googleads___v4___enums___promotion_extension_discount_modifier_pb2___PromotionExtensionDiscountModifierEnum.PromotionExtensionDiscountModifierValue
        ] = None,
        promotion_start_date: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        promotion_end_date: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        occasion: typing___Optional[
            google___ads___googleads___v4___enums___promotion_extension_occasion_pb2___PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue
        ] = None,
        final_urls: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        final_mobile_urls: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        tracking_url_template: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        url_custom_parameters: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v4___common___custom_parameter_pb2___CustomParameter
            ]
        ] = None,
        final_url_suffix: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        language_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        percent_off: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        money_amount_off: typing___Optional[
            google___ads___googleads___v4___common___feed_common_pb2___Money
        ] = None,
        promotion_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        orders_over_amount: typing___Optional[
            google___ads___googleads___v4___common___feed_common_pb2___Money
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "discount_type",
            b"discount_type",
            "final_url_suffix",
            b"final_url_suffix",
            "language_code",
            b"language_code",
            "money_amount_off",
            b"money_amount_off",
            "orders_over_amount",
            b"orders_over_amount",
            "percent_off",
            b"percent_off",
            "promotion_code",
            b"promotion_code",
            "promotion_end_date",
            b"promotion_end_date",
            "promotion_start_date",
            b"promotion_start_date",
            "promotion_target",
            b"promotion_target",
            "promotion_trigger",
            b"promotion_trigger",
            "tracking_url_template",
            b"tracking_url_template",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "discount_modifier",
            b"discount_modifier",
            "discount_type",
            b"discount_type",
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_url_suffix",
            b"final_url_suffix",
            "final_urls",
            b"final_urls",
            "language_code",
            b"language_code",
            "money_amount_off",
            b"money_amount_off",
            "occasion",
            b"occasion",
            "orders_over_amount",
            b"orders_over_amount",
            "percent_off",
            b"percent_off",
            "promotion_code",
            b"promotion_code",
            "promotion_end_date",
            b"promotion_end_date",
            "promotion_start_date",
            b"promotion_start_date",
            "promotion_target",
            b"promotion_target",
            "promotion_trigger",
            b"promotion_trigger",
            "tracking_url_template",
            b"tracking_url_template",
            "url_custom_parameters",
            b"url_custom_parameters",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["discount_type", b"discount_type"],
    ) -> typing_extensions___Literal["percent_off", "money_amount_off"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "promotion_trigger", b"promotion_trigger"
        ],
    ) -> typing_extensions___Literal["promotion_code", "orders_over_amount"]: ...

type___PromotionFeedItem = PromotionFeedItem

class StructuredSnippetFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def header(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def values(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    def __init__(
        self,
        *,
        header: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        values: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["header", b"header"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "header", b"header", "values", b"values"
        ],
    ) -> None: ...

type___StructuredSnippetFeedItem = StructuredSnippetFeedItem

class SitelinkFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def link_text(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def line1(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def line2(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def final_urls(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def final_mobile_urls(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def tracking_url_template(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def url_custom_parameters(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v4___common___custom_parameter_pb2___CustomParameter
    ]: ...
    @property
    def final_url_suffix(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        link_text: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        line1: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        line2: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        final_urls: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        final_mobile_urls: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        tracking_url_template: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        url_custom_parameters: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v4___common___custom_parameter_pb2___CustomParameter
            ]
        ] = None,
        final_url_suffix: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "final_url_suffix",
            b"final_url_suffix",
            "line1",
            b"line1",
            "line2",
            b"line2",
            "link_text",
            b"link_text",
            "tracking_url_template",
            b"tracking_url_template",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_url_suffix",
            b"final_url_suffix",
            "final_urls",
            b"final_urls",
            "line1",
            b"line1",
            "line2",
            b"line2",
            "link_text",
            b"link_text",
            "tracking_url_template",
            b"tracking_url_template",
            "url_custom_parameters",
            b"url_custom_parameters",
        ],
    ) -> None: ...

type___SitelinkFeedItem = SitelinkFeedItem

class HotelCalloutFeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def text(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def language_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        text: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        language_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "language_code", b"language_code", "text", b"text"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "language_code", b"language_code", "text", b"text"
        ],
    ) -> None: ...

type___HotelCalloutFeedItem = HotelCalloutFeedItem



from typing import Any

class AssetServiceStub:
    GetAsset: Any = ...
    MutateAssets: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AssetServiceServicer:
    def GetAsset(self, request: Any, context: Any) -> None: ...
    def MutateAssets(self, request: Any, context: Any) -> None: ...

def add_AssetServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomerPayPerConversionEligibilityFailureReasonEnum(
    google___protobuf___message___Message
):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CustomerPayPerConversionEligibilityFailureReasonValue = typing___NewType(
        "CustomerPayPerConversionEligibilityFailureReasonValue", builtin___int
    )
    type___CustomerPayPerConversionEligibilityFailureReasonValue = (
        CustomerPayPerConversionEligibilityFailureReasonValue
    )
    CustomerPayPerConversionEligibilityFailureReason: _CustomerPayPerConversionEligibilityFailureReason
    class _CustomerPayPerConversionEligibilityFailureReason(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
            0,
        )
        UNKNOWN = typing___cast(
            CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
            1,
        )
        NOT_ENOUGH_CONVERSIONS = typing___cast(
            CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
            2,
        )
        CONVERSION_LAG_TOO_HIGH = typing___cast(
            CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
            3,
        )
        HAS_CAMPAIGN_WITH_SHARED_BUDGET = typing___cast(
            CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
            4,
        )
        HAS_UPLOAD_CLICKS_CONVERSION = typing___cast(
            CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
            5,
        )
        AVERAGE_DAILY_SPEND_TOO_HIGH = typing___cast(
            CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
            6,
        )
        ANALYSIS_NOT_COMPLETE = typing___cast(
            CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
            7,
        )
        OTHER = typing___cast(
            CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
            8,
        )
    UNSPECIFIED = typing___cast(
        CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
        0,
    )
    UNKNOWN = typing___cast(
        CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
        1,
    )
    NOT_ENOUGH_CONVERSIONS = typing___cast(
        CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
        2,
    )
    CONVERSION_LAG_TOO_HIGH = typing___cast(
        CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
        3,
    )
    HAS_CAMPAIGN_WITH_SHARED_BUDGET = typing___cast(
        CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
        4,
    )
    HAS_UPLOAD_CLICKS_CONVERSION = typing___cast(
        CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
        5,
    )
    AVERAGE_DAILY_SPEND_TOO_HIGH = typing___cast(
        CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
        6,
    )
    ANALYSIS_NOT_COMPLETE = typing___cast(
        CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
        7,
    )
    OTHER = typing___cast(
        CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue,
        8,
    )
    type___CustomerPayPerConversionEligibilityFailureReason = (
        CustomerPayPerConversionEligibilityFailureReason
    )
    def __init__(self,) -> None: ...

type___CustomerPayPerConversionEligibilityFailureReasonEnum = (
    CustomerPayPerConversionEligibilityFailureReasonEnum
)
